function vals = biv_normalPdf(points,mu1,sigma1,mu2,sigma2,rho)
% calculate bivariate normal pdf
%
% Inputs:
%   points      nx2 matrix containing points for evalution
%   mu1         mu value of first margin
%   sigma1      sigma value of first margin
%   mu2         mu value of second margin
%   sigma2      sigma value of second margin
%   rho         correlation parameter
%
% Outputs:
%   vals        nx1 vector containing pdf value for each point

preFactor = (2*pi*sigma1*sigma2*sqrt(1-rho^2)).^(-1);
backTerm = exp(-1/(2*(1-rho^2))*( (points(:,1)-mu1).^2/sigma1^2 +...
    (points(:,2).^2)/sigma2^2 - ...
    2*rho*(points(:,1)-mu1).*(points(:,2)-mu2)/(sigma1*sigma2)));

vals = preFactor .* backTerm;

end
