function pdfVals = clayton_pdf(param,U)
% Clayton copula density  evalution
%
  % Inputs:
  %   param      copula parameter
  %   U          nx2 matrix containing points that 
  %              shall be evaluated
%
  % Outputs:
  %   pdfVals    nx1 vector containing associated 
  %              pdf values

% error checking
if(param < 1)
    error('Clayton parameter must be larger than 1');
end

if(any(any(U<0)) || any(any(U>1)))
error('Copulas do only live on unit square')
end

% do not allow values on boundaries: infinity
eps = 1e-8;
U(U==0) = eps;
U(U==1) = 1-eps;

  theta = param; 
u1 = U(:,1);
u2 = U(:,2);

pdfVals = (1+theta)*(u1.*u2).^(-theta-1).*...
 (u1.^-theta + u2.^-theta-1).^(-1/theta-2);

end
