function [paramsHat time] = global_tCop_fit(rets1,rets2)
% fit t-copula with t-margins globally

tic 

% optimization
optFun = @(x)neg_t_model_llh(rets1,rets2,x);
lb = [1 1 -0.99 1];
ub = [inf inf 0.99 inf];

paramsHat = fmincon(optFun,[3 3 0.5 3],[],[],[],[],lb,ub);

time = toc;

end



function pdfVals = t_model_pdf(rets1,rets2,params)
% get pdf values at data points with given parameters

% extract params
nu1 = params(1);
nu2 = params(2);
rho = params(3);
nuCop = params(4);

% transform data points to quantile domain
U1 = tcdf(rets1,nu1);
U2 = tcdf(rets2,nu2);

% evaluate copula at PITs
copPdfVals = copulapdf('t',[U1 U2],rho,nuCop);

% evaluate individual marginal distributions
mPdfVals1 = tpdf(rets1,nu1);
mPdfVals2 = tpdf(rets2,nu2);

pdfVals = copPdfVals.*mPdfVals1.*mPdfVals2;

end

function nLLH = neg_t_model_llh(rets1,rets2,params)
% calculate negative log-likelihood

pdfVals = t_model_pdf(rets1,rets2,params);
nLLH = -sum(log(pdfVals));

end