function Y = log_port_ret(X,weights)
% calculate logarithmic portfolio returns for given weights
%
% Inputs:
%   X       nxd matrix containing returns of d assets
%   weights     1xd vector of portfolio weights, summing up to 1
%
% Outputs:
%   Y       nx1 matrix containing portfolio returns
%
% Jun.2012

% get number of observations
nObs = numel(X(:,1));

% guarantee weights summing up to one
weights = weights/sum(weights);

% extend weights
weights = repmat(weights,nObs,1);

% calculate portfolio returns
Y = log(sum(weights.* exp(X),2));